GridSnapshot class

Immutable grid settings snapshot.

Constructors

GridSnapshot({bool isEnabled = false, double cellSize = SceneDefaults.gridCellSize, Color color = const Color(0x1F000000)})
const

Properties

cellSize double
final
color Color
final
hashCode int
The hash code for this object.
no setterinherited
isEnabled bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited