ImageNodeSnapshot class

Inheritance

Constructors

ImageNodeSnapshot({required NodeId id, required String imageId, required Size size, Size? naturalSize, Transform2D transform = Transform2D.identity, double opacity = 1, double hitPadding = 0, bool isVisible = true, bool isSelectable = true, bool isLocked = false, bool isDeletable = true, bool isTransformable = true})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hitPadding double
finalinherited
id → NodeId
finalinherited
imageId String
final
isDeletable bool
finalinherited
isLocked bool
finalinherited
isSelectable bool
finalinherited
isTransformable bool
finalinherited
isVisible bool
finalinherited
naturalSize Size?
final
opacity double
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size
final
transform Transform2D
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited