LineNodePatch class

Inheritance

Constructors

LineNodePatch({required NodeId id, CommonNodePatch? common, PatchField<Offset> start = const PatchField<Offset>.absent(), PatchField<Offset> end = const PatchField<Offset>.absent(), PatchField<double> thickness = const PatchField<double>.absent(), PatchField<Color> color = const PatchField<Color>.absent()})
const

Properties

color PatchField<Color>
final
common CommonNodePatch
finalinherited
end PatchField<Offset>
final
hashCode int
The hash code for this object.
no setterinherited
id → NodeId
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start PatchField<Offset>
final
thickness PatchField<double>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited