PatchField<T> class

Constructors

PatchField.absent()
const
PatchField.nullValue()
const
PatchField.value(T value)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hasValue bool
no setter
isAbsent bool
no setter
isNullValue bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state PatchFieldState
final
value → T
no setter
valueOrNull → T?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited