PathNodePatch class

Inheritance

Constructors

PathNodePatch({required NodeId id, CommonNodePatch? common, PatchField<String> svgPathData = const PatchField<String>.absent(), PatchField<Color?> fillColor = const PatchField<Color?>.absent(), PatchField<Color?> strokeColor = const PatchField<Color?>.absent(), PatchField<double> strokeWidth = const PatchField<double>.absent(), PatchField<V2PathFillRule> fillRule = const PatchField<V2PathFillRule>.absent()})
const

Properties

common CommonNodePatch
finalinherited
fillColor PatchField<Color?>
final
fillRule PatchField<V2PathFillRule>
final
hashCode int
The hash code for this object.
no setterinherited
id → NodeId
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeColor PatchField<Color?>
final
strokeWidth PatchField<double>
final
svgPathData PatchField<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited