PathNodeSpec class
Constructors
- PathNodeSpec({NodeId? id, required String svgPathData, Color? fillColor, Color? strokeColor, double strokeWidth = 1, V2PathFillRule fillRule = V2PathFillRule.nonZero, Transform2D transform = Transform2D.identity, double opacity = 1, double hitPadding = 0, bool isVisible = true, bool isSelectable = true, bool isLocked = false, bool isDeletable = true, bool isTransformable = true})
Properties
- fillColor → Color?
-
final
- fillRule → V2PathFillRule
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hitPadding → double
-
finalinherited
- id → NodeId?
-
finalinherited
- isDeletable → bool
-
finalinherited
- isLocked → bool
-
finalinherited
- isSelectable → bool
-
finalinherited
- isTransformable → bool
-
finalinherited
- isVisible → bool
-
finalinherited
- opacity → double
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strokeColor → Color?
-
final
- strokeWidth → double
-
final
- svgPathData → String
-
final
- transform → Transform2D
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited