RectNodePatch class

Inheritance

Constructors

RectNodePatch({required NodeId id, CommonNodePatch? common, PatchField<Size> size = const PatchField<Size>.absent(), PatchField<Color?> fillColor = const PatchField<Color?>.absent(), PatchField<Color?> strokeColor = const PatchField<Color?>.absent(), PatchField<double> strokeWidth = const PatchField<double>.absent()})
const

Properties

common CommonNodePatch
finalinherited
fillColor PatchField<Color?>
final
hashCode int
The hash code for this object.
no setterinherited
id → NodeId
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size PatchField<Size>
final
strokeColor PatchField<Color?>
final
strokeWidth PatchField<double>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited