SceneControllerInteractiveV2 class
- Inheritance
-
- Object
- ChangeNotifier
- SceneControllerInteractiveV2
Constructors
- SceneControllerInteractiveV2({Scene? scene, SceneSnapshot? initialSnapshot, PointerInputSettings? pointerSettings, double? dragStartSlop, bool clearSelectionOnDrawModeEnter = false})
Properties
-
actions
→ Stream<
ActionCommitted> -
no setter
- activeLinePreviewColor → Color
-
no setter
- activeLinePreviewEnd → Offset?
-
no setter
- activeLinePreviewStart → Offset?
-
no setter
- activeLinePreviewThickness → double
-
no setter
- activeStrokePreviewColor → Color
-
no setter
- activeStrokePreviewOpacity → double
-
no setter
-
activeStrokePreviewPoints
→ List<
Offset> -
no setter
- activeStrokePreviewThickness → double
-
no setter
- boundsRevision → int
-
no setter
- clearSelectionOnDrawModeEnter → bool
-
final
- controllerEpoch → int
-
no setter
- core → SceneControllerV2
-
no setter
- dragStartSlop → double
-
no setter
- drawColor → Color
-
no setter
- drawTool → DrawTool
-
no setter
-
editTextRequests
→ Stream<
EditTextRequested> -
no setter
- eraserThickness ↔ double
-
getter/setter pair
- hasActiveLinePreview → bool
-
no setter
- hasActiveStrokePreview → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- hasPendingLineStart → bool
-
no setter
- highlighterOpacity ↔ double
-
getter/setter pair
- highlighterThickness ↔ double
-
getter/setter pair
- lineThickness ↔ double
-
getter/setter pair
- mode → CanvasMode
-
no setter
- pendingLineStart → Offset?
-
no setter
- pendingLineTimestampMs → int?
-
no setter
- penThickness ↔ double
-
getter/setter pair
- pointerSettings → PointerInputSettings
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scene → Scene
-
no setter
-
selectedNodeIds
→ Set<
NodeId> -
no setter
- selectionRect → Rect?
-
no setter
- snapshot → SceneSnapshot
-
no setter
- structuralRevision → int
-
no setter
- visualRevision → int
-
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
addNode(
Object node, {int? layerIndex}) → String -
clearScene(
{int? timestampMs}) → void -
clearSelection(
) → void -
deleteSelection(
{int? timestampMs}) → void -
dispose(
) → void -
Discards any resources used by the object.
override
-
flipSelectionHorizontal(
{int? timestampMs}) → void -
flipSelectionVertical(
{int? timestampMs}) → void -
handlePointer(
PointerSample sample) → void -
handlePointerSignal(
PointerSignal signal) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
notifySceneChanged(
) → void -
patchNode(
NodePatch patch) → bool -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
removeNode(
NodeId id, {int? timestampMs}) → bool -
replaceScene(
SceneSnapshot snapshot) → void -
rotateSelection(
{required bool clockwise, int? timestampMs}) → void -
selectAll(
{bool onlySelectable = true}) → void -
setBackgroundColor(
Color value) → void -
setCameraOffset(
Offset value) → void -
setDragStartSlop(
double? value) → void -
setDrawColor(
Color value) → void -
setDrawTool(
DrawTool value) → void -
setGridCellSize(
double value) → void -
setGridEnabled(
bool value) → void -
setMode(
CanvasMode value) → void -
setPointerSettings(
PointerInputSettings value) → void -
setSelection(
Iterable< NodeId> nodeIds) → void -
toggleSelection(
NodeId nodeId) → void -
toString(
) → String -
A string representation of this object.
inherited
-
write<
T> (T fn(SceneWriter writer)) → T
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited