SceneStaticLayerCacheV2 class

Constructors

SceneStaticLayerCacheV2()

Properties

debugBuildCount int
no setter
debugDisposeCount int
no setter
debugKeyHashCode int?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
dispose() → void
draw(Canvas canvas, Size size, {required BackgroundSnapshot background, required Offset cameraOffset, required double gridStrokeWidth}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited