SceneTextLayoutCacheV2 class

Constructors

SceneTextLayoutCacheV2({int maxEntries = 256})

Properties

debugBuildCount int
no setter
debugEvictCount int
no setter
debugHitCount int
no setter
debugSize int
no setter
hashCode int
The hash code for this object.
no setterinherited
maxEntries int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
getOrBuild({required TextNodeSnapshot node, required TextStyle textStyle, required double maxWidth, TextDirection textDirection = TextDirection.ltr}) TextPainter
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited