StrokeNodeSnapshot class

Inheritance

Constructors

StrokeNodeSnapshot({required NodeId id, required List<Offset> points, required double thickness, required Color color, Transform2D transform = Transform2D.identity, double opacity = 1, double hitPadding = 0, bool isVisible = true, bool isSelectable = true, bool isLocked = false, bool isDeletable = true, bool isTransformable = true})

Properties

color Color
final
hashCode int
The hash code for this object.
no setterinherited
hitPadding double
finalinherited
id → NodeId
finalinherited
isDeletable bool
finalinherited
isLocked bool
finalinherited
isSelectable bool
finalinherited
isTransformable bool
finalinherited
isVisible bool
finalinherited
opacity double
finalinherited
points List<Offset>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thickness double
final
transform Transform2D
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited