TextNodePatch class

Inheritance

Constructors

TextNodePatch({required NodeId id, CommonNodePatch? common, PatchField<String> text = const PatchField<String>.absent(), PatchField<Size> size = const PatchField<Size>.absent(), PatchField<double> fontSize = const PatchField<double>.absent(), PatchField<Color> color = const PatchField<Color>.absent(), PatchField<TextAlign> align = const PatchField<TextAlign>.absent(), PatchField<bool> isBold = const PatchField<bool>.absent(), PatchField<bool> isItalic = const PatchField<bool>.absent(), PatchField<bool> isUnderline = const PatchField<bool>.absent(), PatchField<String?> fontFamily = const PatchField<String?>.absent(), PatchField<double?> maxWidth = const PatchField<double?>.absent(), PatchField<double?> lineHeight = const PatchField<double?>.absent()})
const

Properties

align PatchField<TextAlign>
final
color PatchField<Color>
final
common CommonNodePatch
finalinherited
fontFamily PatchField<String?>
final
fontSize PatchField<double>
final
hashCode int
The hash code for this object.
no setterinherited
id → NodeId
finalinherited
isBold PatchField<bool>
final
isItalic PatchField<bool>
final
isUnderline PatchField<bool>
final
lineHeight PatchField<double?>
final
maxWidth PatchField<double?>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size PatchField<Size>
final
text PatchField<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited