TextNodeSnapshot class

Inheritance

Constructors

TextNodeSnapshot({required NodeId id, required String text, required Size size, double fontSize = 24, required Color color, TextAlign align = TextAlign.left, bool isBold = false, bool isItalic = false, bool isUnderline = false, String? fontFamily, double? maxWidth, double? lineHeight, Transform2D transform = Transform2D.identity, double opacity = 1, double hitPadding = 0, bool isVisible = true, bool isSelectable = true, bool isLocked = false, bool isDeletable = true, bool isTransformable = true})
const

Properties

align TextAlign
final
color Color
final
fontFamily String?
final
fontSize double
final
hashCode int
The hash code for this object.
no setterinherited
hitPadding double
finalinherited
id → NodeId
finalinherited
isBold bool
final
isDeletable bool
finalinherited
isItalic bool
final
isLocked bool
finalinherited
isSelectable bool
finalinherited
isTransformable bool
finalinherited
isUnderline bool
final
isVisible bool
finalinherited
lineHeight double?
final
maxWidth double?
final
opacity double
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size
final
text String
final
transform Transform2D
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited