distancePointToSegment function
Returns the shortest distance from point to the segment a-b.
Implementation
double distancePointToSegment(Offset point, Offset a, Offset b) {
return math.sqrt(distanceSquaredPointToSegment(point, a, b));
}
Returns the shortest distance from point to the segment a-b.
double distancePointToSegment(Offset point, Offset a, Offset b) {
return math.sqrt(distanceSquaredPointToSegment(point, a, b));
}