CommonNodePatch class
Patch for common node fields shared by all node variants.
Constructors
-
CommonNodePatch({PatchField<
Transform2D> transform = const PatchField<Transform2D>.absent(), PatchField<double> opacity = const PatchField<double>.absent(), PatchField<double> hitPadding = const PatchField<double>.absent(), PatchField<bool> isVisible = const PatchField<bool>.absent(), PatchField<bool> isSelectable = const PatchField<bool>.absent(), PatchField<bool> isLocked = const PatchField<bool>.absent(), PatchField<bool> isDeletable = const PatchField<bool>.absent(), PatchField<bool> isTransformable = const PatchField<bool>.absent()}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hitPadding
→ PatchField<
double> -
final
-
isDeletable
→ PatchField<
bool> -
final
-
isLocked
→ PatchField<
bool> -
final
-
isSelectable
→ PatchField<
bool> -
final
-
isTransformable
→ PatchField<
bool> -
final
-
isVisible
→ PatchField<
bool> -
final
-
opacity
→ PatchField<
double> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
transform
→ PatchField<
Transform2D> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited