ImageNodePatch class
Constructors
-
ImageNodePatch({required NodeId id, CommonNodePatch? common, PatchField<
String> imageId = const PatchField<String>.absent(), PatchField<Size> size = const PatchField<Size>.absent(), PatchField<Size?> naturalSize = const PatchField<Size?>.absent()}) -
const
Properties
- common → CommonNodePatch
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → NodeId
-
finalinherited
-
imageId
→ PatchField<
String> -
final
-
naturalSize
→ PatchField<
Size?> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
size
→ PatchField<
Size> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited