LayerSnapshot class
Immutable layer snapshot.
Constructors
-
LayerSnapshot({List<
NodeSnapshot> ? nodes, bool isBackground = false})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBackground → bool
-
final
-
nodes
→ List<
NodeSnapshot> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited