SceneSnapshot class
Immutable scene snapshot exposed by the v2 public API.
Constructors
-
SceneSnapshot({List<
LayerSnapshot> ? layers, CameraSnapshot? camera, BackgroundSnapshot? background, ScenePaletteSnapshot? palette})
Properties
- background → BackgroundSnapshot
-
final
- camera → CameraSnapshot
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
layers
→ List<
LayerSnapshot> -
final
- palette → ScenePaletteSnapshot
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited