SceneStrokePathCacheV2 class
Constructors
- SceneStrokePathCacheV2({int maxEntries = 512})
Properties
- debugBuildCount → int
-
no setter
- debugEvictCount → int
-
no setter
- debugHitCount → int
-
no setter
- debugSize → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxEntries → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → void -
getOrBuild(
StrokeNodeSnapshot node) → Path -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited