StrokeNodePatch class
Constructors
-
StrokeNodePatch({required NodeId id, CommonNodePatch? common, PatchField<
List< points = const PatchField<List<Offset>>.absent(), PatchField<Offset> >double> thickness = const PatchField<double>.absent(), PatchField<Color> color = const PatchField<Color>.absent()}) -
const
Properties
-
color
→ PatchField<
Color> -
final
- common → CommonNodePatch
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → NodeId
-
finalinherited
-
points
→ PatchField<
List< Offset> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
thickness
→ PatchField<
double> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited